Index: trunk/ippToPsps/jython/forcedwarpbatch.py
===================================================================
--- trunk/ippToPsps/jython/forcedwarpbatch.py	(revision 38759)
+++ trunk/ippToPsps/jython/forcedwarpbatch.py	(revision 38763)
@@ -279,5 +279,5 @@
 #        self.scratchDb.updateFilterID("ForcedWarpMeta", self.filterID)
         self.scratchDb.updateFilterID("ForcedWarpMeta_"+forcedWarpID,self.filterName[num][0])
-        self.scratchDb.updateAllRows("ForcedWarpMeta_"+forcedWarpID, "dataRelease", str(self.skychunk.dataRelease))
+        self.scratchDb.updateAllRows("ForcedWarpMeta_"+forcedWarpID, "processingVersion", str(self.skychunk.processingVersion))
         #self.tablesToExport.append("ForcedWarpMeta")
        
@@ -379,5 +379,5 @@
         sqlLine.group("FinfoFlag","FLAGS")
         sqlLine.group("FinfoFlag2","FLAGS2")
-        sqlLine.group("dataRelease",str(self.skychunk.dataRelease))
+        sqlLine.group("processingVersion",str(self.skychunk.processingVersion))
 
         print "got here too"
@@ -393,5 +393,5 @@
 
 
         # insert the per-object data (IDs, random stack ID, dataRelease, etc)
         #self.selectDvoObjIDs()
         self.logger.infoPair("inserting dvo info: find imageID","from externID")
@@ -393,5 +393,5 @@
 
 
-        # insert the per-object data (IDs, random stack ID, dataRelease, etc)
+        # insert the per-object data (IDs, random stack ID, processingVersion, etc)
         #self.selectDvoObjIDs()
         self.logger.infoPair("inserting dvo info: find imageID","from externID")
